# Google Drive changelog

## [0.1.10] - 2026-01-15
- Updated connector definition (YAML version 0.1.1)
- Source commit: a23d9e7a
- SDK version: 0.1.0

## [0.1.9] - 2026-01-14
- Updated connector definition (YAML version 0.1.1)
- Source commit: 7ef09816
- SDK version: 0.1.0

## [0.1.8] - 2026-01-14
- Updated connector definition (YAML version 0.1.1)
- Source commit: e6285db5
- SDK version: 0.1.0

## [0.1.7] - 2026-01-14
- Updated connector definition (YAML version 0.1.1)
- Source commit: 31de238d
- SDK version: 0.1.0

## [0.1.6] - 2026-01-13
- Updated connector definition (YAML version 0.1.1)
- Source commit: e80a226e
- SDK version: 0.1.0

## [0.1.5] - 2026-01-13
- Updated connector definition (YAML version 0.1.1)
- Source commit: 78b1be67
- SDK version: 0.1.0

## [0.1.4] - 2026-01-11
- Updated connector definition (YAML version 0.1.1)
- Source commit: e519b73d
- SDK version: 0.1.0

## [0.1.3] - 2026-01-09
- Updated connector definition (YAML version 0.1.1)
- Source commit: 3c7bfdfd
- SDK version: 0.1.0

## [0.1.2] - 2026-01-09
- Updated connector definition (YAML version 0.1.1)
- Source commit: 3bcb33e8
- SDK version: 0.1.0

## [0.1.1] - 2026-01-09
- Updated connector definition (YAML version 0.1.1)
- Source commit: da9b741b
- SDK version: 0.1.0

## [0.1.0] - 2026-01-08
- Updated connector definition (YAML version 0.1.1)
- Source commit: a87e3446
- SDK version: 0.1.0
